module.exports = function(grunt) {
    grunt.initConfig({

        pkg: grunt.file.readJSON('package.json'),

        clean: {
            clean: [
                "dist",
                "src/tbBootstrapMin",
                "src/tbBootstrap"
            ]
        },

        concat: {
            options: {
                separator: '\n\n',
                //stripBanners: true,
                banner: '/*! <%= pkg.name %> - v<%= pkg.version %> - <%= grunt.template.today("yyyy-mm-dd") %> */\n\n'
            },
            dist: {
                files: {
                    'src/tbBootstrap/tbBootstrap.js': [
                        'src/tbBootstrapSources/bootstrap.js',
                        'src/tbBootstrapSources/elements/Panel.js'
                    ]
                },
                nonull: true
            }
        },

        copy: {
            main: {
                files: [
                    {
                        expand: true,
                        cwd: 'src/tbBootstrap',
                        src: '*.js',
                        dest: 'dist/tbBootstrap'
                    },
                    {
                        expand: true,
                        cwd: 'src/tbBootstrapMin',
                        src: '*.js',
                        dest: 'dist/tbBootstrap'
                    },
                    {
                        expand: true,
                        cwd: 'src/tbBootstrapMin',
                        src: '*.js.map',
                        dest: 'dist/tbBootstrap'
                    },
                    {
                        expand: true,
                        cwd: 'src/bootstrap',
                        src: '**/*.*',
                        dest: 'dist/bootstrap'
                    },
                    {
                        expand: true,
                        cwd: 'src/twobirds-core/tb',
                        src: '*.*',
                        dest: 'dist/tb'
                    },
                    {
                        expand: true,
                        cwd: 'src/jquery',
                        src: '*.*',
                        dest: 'dist/jquery'
                    }
                ]
            }
        },

        uglify: {
            options: {
                mangle: {
                    //except:	['jQuery']
                }
            },
            my_target: {
                options: {
                    mangle: false
                },
                files: [
                    {
                        'src/tbBootstrapMin/tbBootstrap.min.js': [
                            'src/tbBootstrap/tbBootstrap.js'
                        ]
                    }
                ]
            }
        },

        jshint: {
            options: {
                esnext: true,
                force: true,
                curly: true,
                eqeqeq: true,
                immed: true,
                latedef: false,
                newcap: false,
                noarg: false,
                sub: true,
                undef: true,
                boss: true,
                debug: true,
                eqnull: true,
                node: true,
                laxbreak: true,
                laxcomma: true,
                shadow:true,
                globals: {
                    exports: true,
                    module: false,
                    tb: true,
                    "window": false,
                    "document": false,
                    "HTMLCollection": false,
                    "NodeList": false,
                    "XMLHttpRequest": false,
                    "ActiveXObject": false
                }
            },
            all: [
                'src/tbBootstrap/tbBootstrap.js'
            ]
        },

        yuidoc: {
            compile: {
                name: 'twobirds-bootstrap',
                description: 'twoBirds Bootstrap Wrapper',
                version: 'v<%= pkg.version%>',
                url: 'http://www.tb-core.org',
                options: {
                    linkNatives: "true",
                    paths: 'src/tbBootstrap',
                    outdir: 'dist/docs/'
                }
            }
        }

    });

    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-copy');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-compress');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-yuidoc');
    grunt.loadNpmTasks('grunt-contrib-jshint');

    // Default task(s).
    grunt.registerTask(
        'default', [
            'clean',
            'concat',
            'uglify',
            'jshint',
            'copy:main',
            'yuidoc'
        ]
    );

};
