tb.namespace( 'bootstrap.Panel' ).set(
    (function(){

        // variables
        var modifiers = [
                'default',
                'primary',
                'success',
                'info',
                'warning',
                'danger'
            ],
            modifierPrefix = 'panel-',
            modifierClasses = modifiers.map( function( pModifier ){ return modifierPrefix + pModifier; } );

        // constructor
        function Panel( pConfig, pTarget ){
            var that = this,
                pConfig = !!pConfig ? pConfig : {},
                defaultConfig = {
                    type: 'default'
                };

            that.config = tb.extend( defaultConfig, pConfig );

            that.target = pTarget;

            that.render();

        }

        // prototype
        Panel.prototype = {

            namespace: 'bootstrap.Panel',

            render: render,

            set: set,

            get: get

        };

        return Panel;



        // private functions
        function render(){
            var that = this;

            tb.dom( that.target )
                .empty();

            that.set();

            // heading
            if ( !!that.config.heading ){
                that.target
                    .append(
                        tb.dom(
                            '<div class="panel-heading"><span class="panel-title">'
                            + ( that.config.heading.textContent || '' )
                            + '</span></div>'
                        )
                    );
            }

            // body
            if ( !!that.config.body ){
                that.target
                    .append(
                        tb.dom(
                            '<div class="panel-body">'
                            + ( that.config.heading.textContent || '' )
                            + '</div>'
                        )
                    );
            }

            // footer
            if ( !!that.config.footer ){
                that.target
                    .append(
                        tb.dom(
                            '<div class="panel-footer"><span class="panel-title">'
                            + ( that.config.footer.textContent || '' )
                            + '</span></div>'
                        )
                    );
            }

        }

        function set( pType ){
            var that = this,
                type = pType || that.config.type;

            if ( type in modifiers ){ // a modifier that is allowed...

                tb.dom( that.target )
                    .removeClass( modifierClasses.join(' ') )
                    .addClass( modifierPrefix + type );

                that.type = type;

            }

            return that.type;
        }

        function get(){

            return this.type;

        }

    })()
);